==> tomee-project-8.0.13-source-release.zip: tomee-project-8.0.13/examples/mp-jwt-bean-validation-strongly-typed/src/main/java/org/superbiz/val/MoviesApp.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.superbiz.val;

import org.eclipse.microprofile.jwt.JsonWebToken;

import javax.validation.ConstraintValidator;
import javax.validation.ConstraintValidatorContext;
import javax.validation.Payload;
import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import static java.lang.annotation.ElementType.ANNOTATION_TYPE;
import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

@Audience("movies")
@javax.validation.Constraint(validatedBy = {MoviesApp.Constraint.class})
@Documented
@Target({METHOD, ANNOTATION_TYPE})
@Retention(RUNTIME)
public @interface MoviesApp {

    Class<?>[] groups() default {};

    String message() default "";

    Class<? extends Payload>[] payload() default {};


    class Constraint implements ConstraintValidator<MoviesApp, JsonWebToken> {
        @Override
        public boolean isValid(final JsonWebToken value, final ConstraintValidatorContext context) {
            return true;
        }
    }

}

==> tomee-project-10.1.3-source-release.zip: tomee-project-10.1.3/examples/mp-jwt-bean-validation-strongly-typed/src/main/java/org/superbiz/val/MoviesApp.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.superbiz.val;

import org.eclipse.microprofile.jwt.JsonWebToken;

import jakarta.validation.ConstraintValidator;
import jakarta.validation.ConstraintValidatorContext;
import jakarta.validation.Payload;
import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import static java.lang.annotation.ElementType.ANNOTATION_TYPE;
import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

@Audience("movies")
@jakarta.validation.Constraint(validatedBy = {MoviesApp.Constraint.class})
@Documented
@Target({METHOD, ANNOTATION_TYPE})
@Retention(RUNTIME)
public @interface MoviesApp {

    Class<?>[] groups() default {};

    String message() default "";

    Class<? extends Payload>[] payload() default {};


    class Constraint implements ConstraintValidator<MoviesApp, JsonWebToken> {
        @Override
        public boolean isValid(final JsonWebToken value, final ConstraintValidatorContext context) {
            return true;
        }
    }

}
